@@ -26,7 +26,7 @@ class DingtalkMessageEvent(AstrMessageEvent):
                 await asyncio.get_event_loop().run_in_executor(
                     None,
                     client.reply_markdown,
-                    "AstrBot",
+                    segment.text,
                     segment.text,
                     self.message_obj.raw_message,
                 )
@@ -54,9 +54,9 @@ class DingtalkMessageEvent(AstrMessageEvent):
                     logger.debug(f"send image: {ret}")
 
                 except Exception as e:
-                    logger.error(f"钉钉图片处理失败: {e}")
-                    logger.warning(f"跳过图片发送: {image_path}")
+                    logger.warning(f"钉钉图片处理失败: {e}, 跳过图片发送")
                     continue
+
     async def send(self, message: MessageChain):
         await self.send_with_client(self.client, message)
         await super().send(message)
