@@ -6,10 +6,11 @@ from .stat import StatRoute
 from .log import LogRoute
 from .static_file import StaticFileRoute
 from .chat import ChatRoute
-from .tools import ToolsRoute  # 导入新的ToolsRoute
+from .tools import ToolsRoute
 from .conversation import ConversationRoute
 from .file import FileRoute
-
+from .session_management import SessionManagementRoute
+from .persona import PersonaRoute
 
 __all__ = [
     "AuthRoute",
@@ -23,4 +24,6 @@ __all__ = [
     "ToolsRoute",
     "ConversationRoute",
     "FileRoute",
+    "SessionManagementRoute",
+    "PersonaRoute",
 ]
