@@ -1,8 +1,16 @@
 import typing
 import traceback
+import os
 from .route import Route, Response, RouteContext
+from astrbot.core.provider.entities import ProviderType
 from quart import request
-from astrbot.core.config.default import CONFIG_METADATA_2, DEFAULT_VALUE_MAP
+from astrbot.core.config.default import (
+    CONFIG_METADATA_2,
+    DEFAULT_VALUE_MAP,
+    CONFIG_METADATA_3,
+    CONFIG_METADATA_3_SYSTEM,
+)
+from astrbot.core.utils.astrbot_path import get_astrbot_path
 from astrbot.core.config.astrbot_config import AstrBotConfig
 from astrbot.core.core_lifecycle import AstrBotCoreLifecycle
 from astrbot.core.platform.register import platform_registry
@@ -10,6 +18,7 @@ from astrbot.core.provider.register import provider_registry
 from astrbot.core.star.star import star_registry
 from astrbot.core import logger
 from astrbot.core.provider import Provider
+from astrbot.core.provider.provider import RerankProvider
 import asyncio
 
 
@@ -146,6 +155,7 @@ def save_config(post_config: dict, config: AstrBotConfig, is_core: bool = False)
         raise ValueError(f"验证配置时出现异常: {e}")
     if errors:
         raise ValueError(f"格式校验未通过: {errors}")
+
     config.save_config(post_config)
 
 
@@ -156,46 +166,129 @@ class ConfigRoute(Route):
         super().__init__(context)
         self.core_lifecycle = core_lifecycle
         self.config: AstrBotConfig = core_lifecycle.astrbot_config
+        self.acm = core_lifecycle.astrbot_config_mgr
         self.routes = {
+            "/config/abconf/new": ("POST", self.create_abconf),
+            "/config/abconf": ("GET", self.get_abconf),
+            "/config/abconfs": ("GET", self.get_abconf_list),
+            "/config/abconf/delete": ("POST", self.delete_abconf),
+            "/config/abconf/update": ("POST", self.update_abconf),
             "/config/get": ("GET", self.get_configs),
             "/config/astrbot/update": ("POST", self.post_astrbot_configs),
             "/config/plugin/update": ("POST", self.post_plugin_configs),
             "/config/platform/new": ("POST", self.post_new_platform),
             "/config/platform/update": ("POST", self.post_update_platform),
             "/config/platform/delete": ("POST", self.post_delete_platform),
+            "/config/platform/list": ("GET", self.get_platform_list),
             "/config/provider/new": ("POST", self.post_new_provider),
             "/config/provider/update": ("POST", self.post_update_provider),
             "/config/provider/delete": ("POST", self.post_delete_provider),
-            "/config/llmtools": ("GET", self.get_llm_tools),
             "/config/provider/check_one": ("GET", self.check_one_provider_status),
             "/config/provider/list": ("GET", self.get_provider_config_list),
             "/config/provider/model_list": ("GET", self.get_provider_model_list),
-            "/config/provider/get_session_seperate": (
-                "GET",
-                lambda: Response()
-                .ok({"enable": self.config["provider_settings"]["separate_provider"]})
-                .__dict__,
-            ),
-            "/config/provider/set_session_seperate": (
-                "POST",
-                self.post_session_seperate,
-            ),
         }
         self.register_routes()
 
+    async def get_abconf_list(self):
+        """获取所有 AstrBot 配置文件的列表"""
+        abconf_list = self.acm.get_conf_list()
+        return Response().ok({"info_list": abconf_list}).__dict__
+
+    async def create_abconf(self):
+        """创建新的 AstrBot 配置文件"""
+        post_data = await request.json
+        if not post_data:
+            return Response().error("缺少配置数据").__dict__
+        umo_parts = post_data["umo_parts"]
+        name = post_data.get("name", None)
+
+        try:
+            conf_id = self.acm.create_conf(umo_parts=umo_parts, name=name)
+            return Response().ok(message="创建成功", data={"conf_id": conf_id}).__dict__
+        except ValueError as e:
+            return Response().error(str(e)).__dict__
+
+    async def get_abconf(self):
+        """获取指定 AstrBot 配置文件"""
+        abconf_id = request.args.get("id")
+        system_config = request.args.get("system_config", "0").lower() == "1"
+        if not abconf_id and not system_config:
+            return Response().error("缺少配置文件 ID").__dict__
+
+        try:
+            if system_config:
+                abconf = self.acm.confs["default"]
+                return (
+                    Response()
+                    .ok({"config": abconf, "metadata": CONFIG_METADATA_3_SYSTEM})
+                    .__dict__
+                )
+            abconf = self.acm.confs[abconf_id]
+            return (
+                Response()
+                .ok({"config": abconf, "metadata": CONFIG_METADATA_3})
+                .__dict__
+            )
+        except ValueError as e:
+            return Response().error(str(e)).__dict__
+
+    async def delete_abconf(self):
+        """删除指定 AstrBot 配置文件"""
+        post_data = await request.json
+        if not post_data:
+            return Response().error("缺少配置数据").__dict__
+
+        conf_id = post_data.get("id")
+        if not conf_id:
+            return Response().error("缺少配置文件 ID").__dict__
+
+        try:
+            success = self.acm.delete_conf(conf_id)
+            if success:
+                return Response().ok(message="删除成功").__dict__
+            else:
+                return Response().error("删除失败").__dict__
+        except ValueError as e:
+            return Response().error(str(e)).__dict__
+        except Exception as e:
+            logger.error(traceback.format_exc())
+            return Response().error(f"删除配置文件失败: {str(e)}").__dict__
+
+    async def update_abconf(self):
+        """更新指定 AstrBot 配置文件信息"""
+        post_data = await request.json
+        if not post_data:
+            return Response().error("缺少配置数据").__dict__
+
+        conf_id = post_data.get("id")
+        if not conf_id:
+            return Response().error("缺少配置文件 ID").__dict__
+
+        name = post_data.get("name")
+        umo_parts = post_data.get("umo_parts")
+
+        try:
+            success = self.acm.update_conf_info(conf_id, name=name, umo_parts=umo_parts)
+            if success:
+                return Response().ok(message="更新成功").__dict__
+            else:
+                return Response().error("更新失败").__dict__
+        except ValueError as e:
+            return Response().error(str(e)).__dict__
+        except Exception as e:
+            logger.error(traceback.format_exc())
+            return Response().error(f"更新配置文件失败: {str(e)}").__dict__
+
     async def _test_single_provider(self, provider):
         """辅助函数：测试单个 provider 的可用性"""
         meta = provider.meta()
         provider_name = provider.provider_config.get("id", "Unknown Provider")
-        logger.debug(f"Got provider meta: {meta}")
-        if not provider_name and meta:
-            provider_name = meta.id
-        elif not provider_name:
-            provider_name = "Unknown Provider"
+        provider_capability_type = meta.provider_type
+
         status_info = {
             "id": getattr(meta, "id", "Unknown ID"),
             "model": getattr(meta, "model", "Unknown Model"),
-            "type": getattr(meta, "type", "Unknown Type"),
+            "type": provider_capability_type.value,
             "name": provider_name,
             "status": "unavailable",  # 默认为不可用
             "error": None,
@@ -203,92 +296,207 @@ class ConfigRoute(Route):
         logger.debug(
             f"Attempting to check provider: {status_info['name']} (ID: {status_info['id']}, Type: {status_info['type']}, Model: {status_info['model']})"
         )
-        try:
-            logger.debug(f"Sending 'Ping' to provider: {status_info['name']}")
-            response = await asyncio.wait_for(
-                provider.text_chat(prompt="REPLY `PONG` ONLY"), timeout=45.0
-            )
-            logger.debug(f"Received response from {status_info['name']}: {response}")
-            # 只要 text_chat 调用成功返回一个 LLMResponse 对象 (即 response 不为 None)，就认为可用
-            if response is not None:
-                status_info["status"] = "available"
-                response_text_snippet = ""
-                if hasattr(response, "completion_text") and response.completion_text:
-                    response_text_snippet = (
-                        response.completion_text[:70] + "..."
-                        if len(response.completion_text) > 70
-                        else response.completion_text
-                    )
-                elif hasattr(response, "result_chain") and response.result_chain:
-                    try:
-                        response_text_snippet = (
-                            response.result_chain.get_plain_text()[:70] + "..."
-                            if len(response.result_chain.get_plain_text()) > 70
-                            else response.result_chain.get_plain_text()
-                        )
-                    except Exception as _:
-                        pass
-                logger.info(
-                    f"Provider {status_info['name']} (ID: {status_info['id']}) is available. Response snippet: '{response_text_snippet}'"
+
+        if provider_capability_type == ProviderType.CHAT_COMPLETION:
+            try:
+                logger.debug(f"Sending 'Ping' to provider: {status_info['name']}")
+                response = await asyncio.wait_for(
+                    provider.text_chat(prompt="REPLY `PONG` ONLY"), timeout=45.0
                 )
-            else:
-                # 这个分支理论上不应该被走到，除非 text_chat 实现可能返回 None
+                logger.debug(
+                    f"Received response from {status_info['name']}: {response}"
+                )
+                if response is not None:
+                    status_info["status"] = "available"
+                    response_text_snippet = ""
+                    if (
+                        hasattr(response, "completion_text")
+                        and response.completion_text
+                    ):
+                        response_text_snippet = (
+                            response.completion_text[:70] + "..."
+                            if len(response.completion_text) > 70
+                            else response.completion_text
+                        )
+                    elif hasattr(response, "result_chain") and response.result_chain:
+                        try:
+                            response_text_snippet = (
+                                response.result_chain.get_plain_text()[:70] + "..."
+                                if len(response.result_chain.get_plain_text()) > 70
+                                else response.result_chain.get_plain_text()
+                            )
+                        except Exception as _:
+                            pass
+                    logger.info(
+                        f"Provider {status_info['name']} (ID: {status_info['id']}) is available. Response snippet: '{response_text_snippet}'"
+                    )
+                else:
+                    status_info["error"] = (
+                        "Test call returned None, but expected an LLMResponse object."
+                    )
+                    logger.warning(
+                        f"Provider {status_info['name']} (ID: {status_info['id']}) test call returned None."
+                    )
+
+            except asyncio.TimeoutError:
                 status_info["error"] = (
-                    "Test call returned None, but expected an LLMResponse object."
+                    "Connection timed out after 45 seconds during test call."
                 )
                 logger.warning(
-                    f"Provider {status_info['name']} (ID: {status_info['id']}) test call returned None."
+                    f"Provider {status_info['name']} (ID: {status_info['id']}) timed out."
+                )
+            except Exception as e:
+                error_message = str(e)
+                status_info["error"] = error_message
+                logger.warning(
+                    f"Provider {status_info['name']} (ID: {status_info['id']}) is unavailable. Error: {error_message}"
+                )
+                logger.debug(
+                    f"Traceback for {status_info['name']}:\n{traceback.format_exc()}"
                 )
 
-        except asyncio.TimeoutError:
-            status_info["error"] = (
-                "Connection timed out after 45 seconds during test call."
-            )
-            logger.warning(
-                f"Provider {status_info['name']} (ID: {status_info['id']}) timed out."
-            )
-        except Exception as e:
-            error_message = str(e)
-            status_info["error"] = error_message
-            logger.warning(
-                f"Provider {status_info['name']} (ID: {status_info['id']}) is unavailable. Error: {error_message}"
-            )
+        elif provider_capability_type == ProviderType.EMBEDDING:
+            try:
+                # For embedding, we can call the get_embedding method with a short prompt.
+                embedding_result = await provider.get_embedding("health_check")
+                if isinstance(embedding_result, list) and (
+                    not embedding_result or isinstance(embedding_result[0], float)
+                ):
+                    status_info["status"] = "available"
+                else:
+                    status_info["status"] = "unavailable"
+                    status_info["error"] = (
+                        f"Embedding test failed: unexpected result type {type(embedding_result)}"
+                    )
+            except Exception as e:
+                logger.error(
+                    f"Error testing embedding provider {provider_name}: {e}",
+                    exc_info=True,
+                )
+                status_info["status"] = "unavailable"
+                status_info["error"] = f"Embedding test failed: {str(e)}"
+
+        elif provider_capability_type == ProviderType.TEXT_TO_SPEECH:
+            try:
+                # For TTS, we can call the get_audio method with a short prompt.
+                audio_result = await provider.get_audio("你好")
+                if isinstance(audio_result, str) and audio_result:
+                    status_info["status"] = "available"
+                else:
+                    status_info["status"] = "unavailable"
+                    status_info["error"] = (
+                        f"TTS test failed: unexpected result type {type(audio_result)}"
+                    )
+            except Exception as e:
+                logger.error(
+                    f"Error testing TTS provider {provider_name}: {e}", exc_info=True
+                )
+                status_info["status"] = "unavailable"
+                status_info["error"] = f"TTS test failed: {str(e)}"
+        elif provider_capability_type == ProviderType.SPEECH_TO_TEXT:
+            try:
+                logger.debug(
+                    f"Sending health check audio to provider: {status_info['name']}"
+                )
+                sample_audio_path = os.path.join(
+                    get_astrbot_path(), "samples", "stt_health_check.wav"
+                )
+                if not os.path.exists(sample_audio_path):
+                    status_info["status"] = "unavailable"
+                    status_info["error"] = (
+                        "STT test failed: sample audio file not found."
+                    )
+                    logger.warning(
+                        f"STT test for {status_info['name']} failed: sample audio file not found at {sample_audio_path}"
+                    )
+                else:
+                    text_result = await provider.get_text(sample_audio_path)
+                    if isinstance(text_result, str) and text_result:
+                        status_info["status"] = "available"
+                        snippet = (
+                            text_result[:70] + "..."
+                            if len(text_result) > 70
+                            else text_result
+                        )
+                        logger.info(
+                            f"Provider {status_info['name']} (ID: {status_info['id']}) is available. Response snippet: '{snippet}'"
+                        )
+                    else:
+                        status_info["status"] = "unavailable"
+                        status_info["error"] = (
+                            f"STT test failed: unexpected result type {type(text_result)}"
+                        )
+                        logger.warning(
+                            f"STT test for {status_info['name']} failed: unexpected result type {type(text_result)}"
+                        )
+            except Exception as e:
+                logger.error(
+                    f"Error testing STT provider {provider_name}: {e}", exc_info=True
+                )
+                status_info["status"] = "unavailable"
+                status_info["error"] = f"STT test failed: {str(e)}"
+        elif provider_capability_type == ProviderType.RERANK:
+            try:
+                assert isinstance(provider, RerankProvider)
+                await provider.rerank("Apple", documents=["apple", "banana"])
+                status_info["status"] = "available"
+            except Exception as e:
+                logger.error(
+                    f"Error testing rerank provider {provider_name}: {e}",
+                    exc_info=True,
+                )
+                status_info["status"] = "unavailable"
+                status_info["error"] = f"Rerank test failed: {str(e)}"
+
+        else:
             logger.debug(
-                f"Traceback for {status_info['name']}:\n{traceback.format_exc()}"
+                f"Provider {provider_name} is not a Chat Completion or Embedding provider. Marking as available without test. Meta: {meta}"
             )
+            status_info["status"] = "available"
+            status_info["error"] = (
+                "This provider type is not tested and is assumed to be available."
+            )
+
         return status_info
 
-    def _error_response(self, message: str, status_code: int = 500, log_fn=logger.error):
+    def _error_response(
+        self, message: str, status_code: int = 500, log_fn=logger.error
+    ):
         log_fn(message)
         # 记录更详细的traceback信息，但只在是严重错误时
         if status_code == 500:
             log_fn(traceback.format_exc())
-        return Response().error(message, status_code=status_code).__dict__
+        return Response().error(message).__dict__
 
     async def check_one_provider_status(self):
         """API: check a single LLM Provider's status by id"""
         provider_id = request.args.get("id")
         if not provider_id:
-            return self._error_response("Missing provider_id parameter", 400, logger.warning)
+            return self._error_response(
+                "Missing provider_id parameter", 400, logger.warning
+            )
 
         logger.info(f"API call: /config/provider/check_one id={provider_id}")
         try:
-            all_providers = self.core_lifecycle.star_context.get_all_providers()
-            # replace manual loop with next(filter(...))
-            target = next(
-                (p for p in all_providers if p.provider_config.get("id") == provider_id),
-                None
-            )
+            prov_mgr = self.core_lifecycle.provider_manager
+            target = prov_mgr.inst_map.get(provider_id)
+
             if not target:
-                return self._error_response(f"Provider with id '{provider_id}' not found", 404, logger.warning)
+                logger.warning(
+                    f"Provider with id '{provider_id}' not found in provider_manager."
+                )
+                return (
+                    Response()
+                    .error(f"Provider with id '{provider_id}' not found")
+                    .__dict__
+                )
 
             result = await self._test_single_provider(target)
             return Response().ok(result).__dict__
 
         except Exception as e:
             return self._error_response(
-                f"Critical error checking provider {provider_id}: {e}",
-                500
+                f"Critical error checking provider {provider_id}: {e}", 500
             )
 
     async def get_configs(self):
@@ -299,29 +507,15 @@ class ConfigRoute(Route):
             return Response().ok(await self._get_astrbot_config()).__dict__
         return Response().ok(await self._get_plugin_config(plugin_name)).__dict__
 
-    async def post_session_seperate(self):
-        """设置提供商会话隔离"""
-        post_config = await request.json
-        enable = post_config.get("enable", None)
-        if enable is None:
-            return Response().error("缺少参数 enable").__dict__
-
-        astrbot_config = self.core_lifecycle.astrbot_config
-        astrbot_config["provider_settings"]["separate_provider"] = enable
-        try:
-            astrbot_config.save_config()
-        except Exception as e:
-            return Response().error(str(e)).__dict__
-        return Response().ok(None, "设置成功~").__dict__
-
     async def get_provider_config_list(self):
         provider_type = request.args.get("provider_type", None)
         if not provider_type:
             return Response().error("缺少参数 provider_type").__dict__
+        provider_type_ls = provider_type.split(",")
         provider_list = []
         astrbot_config = self.core_lifecycle.astrbot_config
         for provider in astrbot_config["provider"]:
-            if provider.get("provider_type", None) == provider_type:
+            if provider.get("provider_type", None) in provider_type_ls:
                 provider_list.append(provider)
         return Response().ok(provider_list).__dict__
 
@@ -347,11 +541,21 @@ class ConfigRoute(Route):
             logger.error(traceback.format_exc())
             return Response().error(str(e)).__dict__
 
+    async def get_platform_list(self):
+        """获取所有平台的列表"""
+        platform_list = []
+        for platform in self.config["platform"]:
+            platform_list.append(platform)
+        return Response().ok({"platforms": platform_list}).__dict__
+
     async def post_astrbot_configs(self):
-        post_configs = await request.json
+        data = await request.json
+        config = data.get("config", None)
+        conf_id = data.get("conf_id", None)
         try:
-            await self._save_astrbot_configs(post_configs)
-            return Response().ok(None, "保存成功~ 机器人正在重载配置。").__dict__
+            await self._save_astrbot_configs(config, conf_id)
+            await self.core_lifecycle.reload_pipeline_scheduler(conf_id)
+            return Response().ok(None, "保存成功~").__dict__
         except Exception as e:
             logger.error(traceback.format_exc())
             return Response().error(str(e)).__dict__
@@ -468,12 +672,6 @@ class ConfigRoute(Route):
             return Response().error(str(e)).__dict__
         return Response().ok(None, "删除成功，已经实时生效~").__dict__
 
-    async def get_llm_tools(self):
-        """获取函数调用工具。包含了本地加载的以及 MCP 服务的工具"""
-        tool_mgr = self.core_lifecycle.provider_manager.llm_tools
-        tools = tool_mgr.get_func_desc_openai_style()
-        return Response().ok(tools).__dict__
-
     async def _get_astrbot_config(self):
         config = self.config
 
@@ -516,10 +714,19 @@ class ConfigRoute(Route):
 
         return ret
 
-    async def _save_astrbot_configs(self, post_configs: dict):
+    async def _save_astrbot_configs(self, post_configs: dict, conf_id: str = None):
         try:
-            save_config(post_configs, self.config, is_core=True)
-            await self.core_lifecycle.restart()
+            if conf_id not in self.acm.confs:
+                raise ValueError(f"配置文件 {conf_id} 不存在")
+            astrbot_config = self.acm.confs[conf_id]
+
+            # 保留服务端的 t2i_active_template 值
+            if "t2i_active_template" in astrbot_config:
+                post_configs["t2i_active_template"] = astrbot_config[
+                    "t2i_active_template"
+                ]
+
+            save_config(post_configs, astrbot_config, is_core=True)
         except Exception as e:
             raise e
 
