@@ -2,7 +2,7 @@ import asyncio
 import json
 from quart import make_response
 from astrbot.core import logger, LogBroker
-from .route import Route, RouteContext
+from .route import Route, RouteContext, Response
 
 
 class LogRoute(Route):
@@ -10,6 +10,9 @@ class LogRoute(Route):
         super().__init__(context)
         self.log_broker = log_broker
         self.app.add_url_rule("/api/live-log", view_func=self.log, methods=["GET"])
+        self.app.add_url_rule(
+            "/api/log-history", view_func=self.log_history, methods=["GET"]
+        )
 
     async def log(self):
         async def stream():
@@ -23,7 +26,6 @@ class LogRoute(Route):
                         **message,  # see astrbot/core/log.py
                     }
                     yield f"data: {json.dumps(payload, ensure_ascii=False)}\n\n"
-                    await asyncio.sleep(0.07)  # 控制发送频率，避免过快
             except asyncio.CancelledError:
                 pass
             except BaseException as e:
@@ -43,3 +45,20 @@ class LogRoute(Route):
         )
         response.timeout = None
         return response
+
+    async def log_history(self):
+        """获取日志历史"""
+        try:
+            logs = list(self.log_broker.log_cache)
+            return (
+                Response()
+                .ok(
+                    data={
+                        "logs": logs,
+                    }
+                )
+                .__dict__
+            )
+        except BaseException as e:
+            logger.error(f"获取日志历史失败: {e}")
+            return Response().error(f"获取日志历史失败: {e}").__dict__
