@@ -1,13 +1,10 @@
-import json
-import os
 import traceback
 
-import aiohttp
 from quart import request
 
 from astrbot.core import logger
 from astrbot.core.core_lifecycle import AstrBotCoreLifecycle
-from astrbot.core.utils.astrbot_path import get_astrbot_data_path
+from astrbot.core.star import star_map
 
 from .route import Response, Route, RouteContext
 
@@ -25,43 +22,17 @@ class ToolsRoute(Route):
             "/tools/mcp/add": ("POST", self.add_mcp_server),
             "/tools/mcp/update": ("POST", self.update_mcp_server),
             "/tools/mcp/delete": ("POST", self.delete_mcp_server),
-            "/tools/mcp/market": ("GET", self.get_mcp_markets),
+            "/tools/mcp/test": ("POST", self.test_mcp_connection),
+            "/tools/list": ("GET", self.get_tool_list),
+            "/tools/toggle-tool": ("POST", self.toggle_tool),
+            "/tools/mcp/sync-provider": ("POST", self.sync_provider),
         }
         self.register_routes()
         self.tool_mgr = self.core_lifecycle.provider_manager.llm_tools
 
-    @property
-    def mcp_config_path(self):
-        data_dir = get_astrbot_data_path()
-        return os.path.join(data_dir, "mcp_server.json")
-
-    def load_mcp_config(self):
-        if not os.path.exists(self.mcp_config_path):
-            # 配置文件不存在，创建默认配置
-            os.makedirs(os.path.dirname(self.mcp_config_path), exist_ok=True)
-            with open(self.mcp_config_path, "w", encoding="utf-8") as f:
-                json.dump(DEFAULT_MCP_CONFIG, f, ensure_ascii=False, indent=4)
-            return DEFAULT_MCP_CONFIG
-
-        try:
-            with open(self.mcp_config_path, "r", encoding="utf-8") as f:
-                return json.load(f)
-        except Exception as e:
-            logger.error(f"加载 MCP 配置失败: {e}")
-            return DEFAULT_MCP_CONFIG
-
-    def save_mcp_config(self, config):
-        try:
-            with open(self.mcp_config_path, "w", encoding="utf-8") as f:
-                json.dump(config, f, ensure_ascii=False, indent=4)
-            return True
-        except Exception as e:
-            logger.error(f"保存 MCP 配置失败: {e}")
-            return False
-
     async def get_mcp_servers(self):
         try:
-            config = self.load_mcp_config()
+            config = self.tool_mgr.load_mcp_config()
             servers = []
 
             # 获取所有服务器并添加它们的工具列表
@@ -124,20 +95,27 @@ class ToolsRoute(Route):
             if not has_valid_config:
                 return Response().error("必须提供有效的服务器配置").__dict__
 
-            config = self.load_mcp_config()
+            config = self.tool_mgr.load_mcp_config()
 
             if name in config["mcpServers"]:
                 return Response().error(f"服务器 {name} 已存在").__dict__
 
             config["mcpServers"][name] = server_config
 
-            if self.save_mcp_config(config):
-                # 动态初始化新MCP客户端
-                await self.tool_mgr.mcp_service_queue.put({
-                    "type": "init",
-                    "name": name,
-                    "cfg": config["mcpServers"][name],
-                })
+            if self.tool_mgr.save_mcp_config(config):
+                try:
+                    await self.tool_mgr.enable_mcp_server(
+                        name, server_config, timeout=30
+                    )
+                except TimeoutError:
+                    return Response().error(f"启用 MCP 服务器 {name} 超时。").__dict__
+                except Exception as e:
+                    logger.error(traceback.format_exc())
+                    return (
+                        Response()
+                        .error(f"启用 MCP 服务器 {name} 失败: {str(e)}")
+                        .__dict__
+                    )
                 return Response().ok(None, f"成功添加 MCP 服务器 {name}").__dict__
             else:
                 return Response().error("保存配置失败").__dict__
@@ -154,7 +132,7 @@ class ToolsRoute(Route):
             if not name:
                 return Response().error("服务器名称不能为空").__dict__
 
-            config = self.load_mcp_config()
+            config = self.tool_mgr.load_mcp_config()
 
             if name not in config["mcpServers"]:
                 return Response().error(f"服务器 {name} 不存在").__dict__
@@ -190,34 +168,58 @@ class ToolsRoute(Route):
 
             config["mcpServers"][name] = server_config
 
-            if self.save_mcp_config(config):
+            if self.tool_mgr.save_mcp_config(config):
                 # 处理MCP客户端状态变化
                 if active:
-                    # 如果要激活服务器或者配置已更改
                     if name in self.tool_mgr.mcp_client_dict or not only_update_active:
-                        await self.tool_mgr.mcp_service_queue.put({
-                            "type": "terminate",
-                            "name": name,
-                        })
-                        await self.tool_mgr.mcp_service_queue.put({
-                            "type": "init",
-                            "name": name,
-                            "cfg": config["mcpServers"][name],
-                        })
-                    else:
-                        # 客户端不存在，初始化
-                        await self.tool_mgr.mcp_service_queue.put({
-                            "type": "init",
-                            "name": name,
-                            "cfg": config["mcpServers"][name],
-                        })
+                        try:
+                            await self.tool_mgr.disable_mcp_server(name, timeout=10)
+                        except TimeoutError as e:
+                            return (
+                                Response()
+                                .error(f"启用前停用 MCP 服务器时 {name} 超时: {str(e)}")
+                                .__dict__
+                            )
+                        except Exception as e:
+                            logger.error(traceback.format_exc())
+                            return (
+                                Response()
+                                .error(f"启用前停用 MCP 服务器时 {name} 失败: {str(e)}")
+                                .__dict__
+                            )
+                    try:
+                        await self.tool_mgr.enable_mcp_server(
+                            name, config["mcpServers"][name], timeout=30
+                        )
+                    except TimeoutError:
+                        return (
+                            Response().error(f"启用 MCP 服务器 {name} 超时。").__dict__
+                        )
+                    except Exception as e:
+                        logger.error(traceback.format_exc())
+                        return (
+                            Response()
+                            .error(f"启用 MCP 服务器 {name} 失败: {str(e)}")
+                            .__dict__
+                        )
                 else:
                     # 如果要停用服务器
                     if name in self.tool_mgr.mcp_client_dict:
-                        self.tool_mgr.mcp_service_queue.put_nowait({
-                            "type": "terminate",
-                            "name": name,
-                        })
+                        try:
+                            await self.tool_mgr.disable_mcp_server(name, timeout=10)
+                        except TimeoutError:
+                            return (
+                                Response()
+                                .error(f"停用 MCP 服务器 {name} 超时。")
+                                .__dict__
+                            )
+                        except Exception as e:
+                            logger.error(traceback.format_exc())
+                            return (
+                                Response()
+                                .error(f"停用 MCP 服务器 {name} 失败: {str(e)}")
+                                .__dict__
+                            )
 
                 return Response().ok(None, f"成功更新 MCP 服务器 {name}").__dict__
             else:
@@ -234,22 +236,28 @@ class ToolsRoute(Route):
             if not name:
                 return Response().error("服务器名称不能为空").__dict__
 
-            config = self.load_mcp_config()
+            config = self.tool_mgr.load_mcp_config()
 
             if name not in config["mcpServers"]:
                 return Response().error(f"服务器 {name} 不存在").__dict__
 
-            # 删除服务器配置
             del config["mcpServers"][name]
 
-            if self.save_mcp_config(config):
-                # 关闭并删除MCP客户端
+            if self.tool_mgr.save_mcp_config(config):
                 if name in self.tool_mgr.mcp_client_dict:
-                    self.tool_mgr.mcp_service_queue.put_nowait({
-                        "type": "terminate",
-                        "name": name,
-                    })
-
+                    try:
+                        await self.tool_mgr.disable_mcp_server(name, timeout=10)
+                    except TimeoutError:
+                        return (
+                            Response().error(f"停用 MCP 服务器 {name} 超时。").__dict__
+                        )
+                    except Exception as e:
+                        logger.error(traceback.format_exc())
+                        return (
+                            Response()
+                            .error(f"停用 MCP 服务器 {name} 失败: {str(e)}")
+                            .__dict__
+                        )
                 return Response().ok(None, f"成功删除 MCP 服务器 {name}").__dict__
             else:
                 return Response().error("保存配置失败").__dict__
@@ -257,27 +265,73 @@ class ToolsRoute(Route):
             logger.error(traceback.format_exc())
             return Response().error(f"删除 MCP 服务器失败: {str(e)}").__dict__
 
-    async def get_mcp_markets(self):
-        page = request.args.get("page", 1, type=int)
-        page_size = request.args.get("page_size", 10, type=int)
-        BASE_URL = (
-            "https://api.soulter.top/astrbot/mcpservers?page={}&page_size={}".format(
-                page,
-                page_size,
-            )
-        )
+    async def test_mcp_connection(self):
+        """
+        测试 MCP 服务器连接
+        """
         try:
-            async with aiohttp.ClientSession() as session:
-                async with session.get(f"{BASE_URL}") as response:
-                    if response.status == 200:
-                        data = await response.json()
-                        return Response().ok(data["data"]).__dict__
-                    else:
-                        return (
-                            Response()
-                            .error(f"获取市场数据失败: HTTP {response.status}")
-                            .__dict__
-                        )
-        except Exception as _:
+            server_data = await request.json
+            config = server_data.get("mcp_server_config", None)
+
+            tools_name = await self.tool_mgr.test_mcp_server_connection(config)
+            return (
+                Response().ok(data=tools_name, message="🎉 MCP 服务器可用！").__dict__
+            )
+
+        except Exception as e:
             logger.error(traceback.format_exc())
-        return Response().error("获取市场数据失败").__dict__
+            return Response().error(f"测试 MCP 连接失败: {str(e)}").__dict__
+
+    async def get_tool_list(self):
+        """获取所有注册的工具列表"""
+        try:
+            tools = self.tool_mgr.func_list
+            tools_dict = [tool.__dict__() for tool in tools]
+            return Response().ok(data=tools_dict).__dict__
+        except Exception as e:
+            logger.error(traceback.format_exc())
+            return Response().error(f"获取工具列表失败: {str(e)}").__dict__
+
+    async def toggle_tool(self):
+        """启用或停用指定的工具"""
+        try:
+            data = await request.json
+            tool_name = data.get("name")
+            action = data.get("activate")  # True or False
+
+            if not tool_name or action is None:
+                return Response().error("缺少必要参数: name 或 action").__dict__
+
+            if action:
+                try:
+                    ok = self.tool_mgr.activate_llm_tool(tool_name, star_map=star_map)
+                except ValueError as e:
+                    return Response().error(f"启用工具失败: {str(e)}").__dict__
+            else:
+                ok = self.tool_mgr.deactivate_llm_tool(tool_name)
+
+            if ok:
+                return Response().ok(None, "操作成功。").__dict__
+            else:
+                return Response().error(f"工具 {tool_name} 不存在或操作失败。").__dict__
+
+        except Exception as e:
+            logger.error(traceback.format_exc())
+            return Response().error(f"操作工具失败: {str(e)}").__dict__
+
+    async def sync_provider(self):
+        """同步 MCP 提供者配置"""
+        try:
+            data = await request.json
+            provider_name = data.get("name")  # modelscope, or others
+            match provider_name:
+                case "modelscope":
+                    access_token = data.get("access_token", "")
+                    await self.tool_mgr.sync_modelscope_mcp_servers(access_token)
+                case _:
+                    return Response().error(f"未知: {provider_name}").__dict__
+
+            return Response().ok(message="同步成功").__dict__
+        except Exception as e:
+            logger.error(traceback.format_exc())
+            return Response().error(f"同步失败: {str(e)}").__dict__
