@@ -8,6 +8,7 @@ from astrbot.api.provider import ProviderRequest
 from astrbot.api.message_components import Plain, Image
 from astrbot import logger
 from collections import defaultdict
+from astrbot.core.astrbot_config_mgr import AstrBotConfigManager
 
 """
 聊天记忆增强
@@ -15,28 +16,46 @@ from collections import defaultdict
 
 
 class LongTermMemory:
-    def __init__(self, config: dict, context: star.Context):
-        self.config = config
+    def __init__(self, acm: AstrBotConfigManager, context: star.Context):
+        self.acm = acm
         self.context = context
         self.session_chats = defaultdict(list)
         """记录群成员的群聊记录"""
+
+    def cfg(self, event: AstrMessageEvent):
+        cfg = self.context.get_config(umo=event.unified_msg_origin)
         try:
-            self.max_cnt = int(self.config["group_message_max_cnt"])
+            max_cnt = int(cfg["provider_ltm_settings"]["group_message_max_cnt"])
         except BaseException as e:
             logger.error(e)
-            self.max_cnt = 300
-        self.image_caption = self.config["image_caption"]
-        self.image_caption_prompt = self.config["image_caption_prompt"]
-        self.image_caption_provider_id = self.config["image_caption_provider_id"]
-
-        self.active_reply = self.config["active_reply"]
-        self.enable_active_reply = self.active_reply.get("enable", False)
-        self.ar_method = self.active_reply["method"]
-        self.ar_possibility = self.active_reply["possibility_reply"]
-        self.ar_prompt = self.active_reply.get("prompt", "")
-        self.ar_whitelist = self.active_reply.get("whitelist", [])
-
-        # self.put_history_to_prompt = self.config["put_history_to_prompt"]
+            max_cnt = 300
+        image_caption = (
+            True
+            if cfg["provider_settings"]["default_image_caption_provider_id"]
+            else False
+        )
+        image_caption_prompt = cfg["provider_settings"]["image_caption_prompt"]
+        image_caption_provider_id = cfg["provider_settings"][
+            "default_image_caption_provider_id"
+        ]
+        active_reply = cfg["provider_ltm_settings"]["active_reply"]
+        enable_active_reply = active_reply.get("enable", False)
+        ar_method = active_reply["method"]
+        ar_possibility = active_reply["possibility_reply"]
+        ar_prompt = active_reply.get("prompt", "")
+        ar_whitelist = active_reply.get("whitelist", [])
+        ret = {
+            "max_cnt": max_cnt,
+            "image_caption": image_caption,
+            "image_caption_prompt": image_caption_prompt,
+            "image_caption_provider_id": image_caption_provider_id,
+            "enable_active_reply": enable_active_reply,
+            "ar_method": ar_method,
+            "ar_possibility": ar_possibility,
+            "ar_prompt": ar_prompt,
+            "ar_whitelist": ar_whitelist,
+        }
+        return ret
 
     async def remove_session(self, event: AstrMessageEvent) -> int:
         cnt = 0
@@ -45,17 +64,17 @@ class LongTermMemory:
             del self.session_chats[event.unified_msg_origin]
         return cnt
 
-    async def get_image_caption(self, image_url: str) -> str:
-        if not self.image_caption_provider_id:
+    async def get_image_caption(
+        self, image_url: str, image_caption_provider_id: str, image_caption_prompt: str
+    ) -> str:
+        if not image_caption_provider_id:
             provider = self.context.get_using_provider()
         else:
-            provider = self.context.get_provider_by_id(self.image_caption_provider_id)
+            provider = self.context.get_provider_by_id(image_caption_provider_id)
             if not provider:
-                raise Exception(
-                    f"没有找到 ID 为 {self.image_caption_provider_id} 的提供商"
-                )
+                raise Exception(f"没有找到 ID 为 {image_caption_provider_id} 的提供商")
         response = await provider.text_chat(
-            prompt=self.image_caption_prompt,
+            prompt=image_caption_prompt,
             session_id=uuid.uuid4().hex,
             image_urls=[image_url],
             persist=False,
@@ -63,7 +82,8 @@ class LongTermMemory:
         return response.completion_text
 
     async def need_active_reply(self, event: AstrMessageEvent) -> bool:
-        if not self.enable_active_reply:
+        cfg = self.cfg(event)
+        if not cfg["enable_active_reply"]:
             return False
         if event.get_message_type() != MessageType.GROUP_MESSAGE:
             return False
@@ -72,15 +92,17 @@ class LongTermMemory:
             # if the message is a command, let it pass
             return False
 
-        if self.ar_whitelist and (
-            event.unified_msg_origin not in self.ar_whitelist
-            and (event.get_group_id() and event.get_group_id() not in self.ar_whitelist)
+        if cfg["ar_whitelist"] and (
+            event.unified_msg_origin not in cfg["ar_whitelist"]
+            and (
+                event.get_group_id() and event.get_group_id() not in cfg["ar_whitelist"]
+            )
         ):
             return False
 
-        match self.ar_method:
+        match cfg["ar_method"]:
             case "possibility_reply":
-                trig = random.random() < self.ar_possibility
+                trig = random.random() < cfg["ar_possibility"]
                 return trig
 
         return False
@@ -92,15 +114,18 @@ class LongTermMemory:
 
             final_message = f"[{event.message_obj.sender.nickname}/{datetime_str}]: "
 
+            cfg = self.cfg(event)
+
             for comp in event.get_messages():
                 if isinstance(comp, Plain):
                     final_message += f" {comp.text}"
                 elif isinstance(comp, Image):
-                    # image_urls.append(comp.url if comp.url else comp.file)
-                    if self.image_caption:
+                    if cfg["image_caption"]:
                         try:
                             caption = await self.get_image_caption(
-                                comp.url if comp.url else comp.file
+                                comp.url if comp.url else comp.file,
+                                cfg["image_caption_provider_id"],
+                                cfg["image_caption_prompt"],
                             )
                             final_message += f" [Image: {caption}]"
                         except Exception as e:
@@ -109,7 +134,7 @@ class LongTermMemory:
                         final_message += " [Image]"
             logger.debug(f"ltm | {event.unified_msg_origin} | {final_message}")
             self.session_chats[event.unified_msg_origin].append(final_message)
-            if len(self.session_chats[event.unified_msg_origin]) > self.max_cnt:
+            if len(self.session_chats[event.unified_msg_origin]) > cfg["max_cnt"]:
                 self.session_chats[event.unified_msg_origin].pop(0)
 
     async def on_req_llm(self, event: AstrMessageEvent, req: ProviderRequest):
@@ -119,7 +144,8 @@ class LongTermMemory:
 
         chats_str = "\n---\n".join(self.session_chats[event.unified_msg_origin])
 
-        if self.enable_active_reply:
+        cfg = self.cfg(event)
+        if cfg["enable_active_reply"]:
             prompt = req.prompt
             req.prompt = f"You are now in a chatroom. The chat history is as follows:\n{chats_str}"
             req.prompt += f"\nNow, a new message is coming: `{prompt}`. Please react to it. Only output your response and do not output any other information."
@@ -135,8 +161,9 @@ class LongTermMemory:
             return
 
         if event.get_result() and event.get_result().is_llm_result():
-            final_message = f"[AstrBot/{datetime.datetime.now().strftime('%H:%M:%S')}]: {event.get_result().get_plain_text()}"
+            final_message = f"[You/{datetime.datetime.now().strftime('%H:%M:%S')}]: {event.get_result().get_plain_text()}"
             logger.debug(f"ltm | {event.unified_msg_origin} | {final_message}")
             self.session_chats[event.unified_msg_origin].append(final_message)
-            if len(self.session_chats[event.unified_msg_origin]) > self.max_cnt:
+            cfg = self.cfg(event)
+            if len(self.session_chats[event.unified_msg_origin]) > cfg["max_cnt"]:
                 self.session_chats[event.unified_msg_origin].pop(0)
